# dmr.py  
[![Stable Version](https://img.shields.io/pypi/v/dmr.py?color=blue)](https://pypi.org/project/dmr.py/)
[![Downloads](https://img.shields.io/pypi/dm/dmr.py)](https://pypistats.org/packages/dmr.py)  

## Installation:  
Install with pip
```
python -m pip install dmr.py
```  

Install current code from this repo, you will need to have git installed in order to do this.
```
python -m pip install git+https://github.com/j4asper/dmr.py
```

## Contributing:
I would be more than happy if those who know how to make pull requests, contribute with code!
